@@ -14,14 +14,7 @@ from typing import Any, Dict, List, Optional, Union
 
 import pandas
 from ML_management.mlmanagement import mlmanager
-from ML_management.mlmanagement.mlmanager import (
-    active_run_stack,
-    is_server,
-    request_for_function,
-)
-
-import mlflow
-from mlflow import ActiveRun
+from ML_management.mlmanagement.mlmanager import active_run_stack, is_server, request_for_function
 from mlflow.entities import Experiment, Run, RunStatus, ViewType
 from mlflow.entities.model_registry import ModelVersion, RegisteredModel
 from mlflow.models import ModelInputExample, ModelSignature
@@ -31,6 +24,9 @@ from mlflow.tracking._model_registry import DEFAULT_AWAIT_MAX_SLEEP_SECONDS
 from mlflow.tracking.fluent import _RUN_ID_ENV_VAR, SEARCH_MAX_RESULTS_PANDAS
 from mlflow.utils import env
 
+import mlflow
+from mlflow import ActiveRun
+
 
 def monkey_patching_exit(self, exc_type, exc_val, exc_tb):
     """Redefine __exit__ function of class ActiveRun."""
@@ -238,6 +234,14 @@ class MlflowClient(object):
             "class_kwargs": {"registry_uri": registry_uri},
         }
 
+    def set_model_version_tag(self, name: str, version: str, key: str, value: Any) -> None:
+        """Set model version tag."""
+        return request_for_function(
+            inspect.currentframe(),
+            extra_attrs=self.extra_attrs,
+            for_class=self.for_class,
+        )
+
     def get_run(self, run_id: str) -> Run:
         """Get run by id."""
         return request_for_function(
@@ -254,6 +258,9 @@ class MlflowClient(object):
             for_class=self.for_class,
         )
 
+    # MlflowClient.search_model_versions always returns all versions in single page with no token
+    # as it uses SqlAlchemyStore on mlflow server pod based on helm Values.mlflow.backendUri
+    # which starts with "postgres". See mlflow/store/model_registry/sqlalchemy_store.py:732
     def search_model_versions(self, filter_string: str) -> PagedList[ModelVersion]:
         """Search for model versions in backend that satisfy the filter criteria."""
         return request_for_function(
@@ -262,9 +269,7 @@ class MlflowClient(object):
             for_class=self.for_class,
         )
 
-    def set_terminated(
-        self, run_id: str, status: Optional[str] = None, end_time: Optional[int] = None
-    ) -> None:
+    def set_terminated(self, run_id: str, status: Optional[str] = None, end_time: Optional[int] = None) -> None:
         """Set a run’s status to terminated."""
         return request_for_function(
             inspect.currentframe(),
@@ -280,9 +285,7 @@ class MlflowClient(object):
             for_class=self.for_class,
         )
 
-    def download_artifacts(
-        self, run_id: str, path: str, dst_path: Optional[str] = None
-    ) -> str:
+    def download_artifacts(self, run_id: str, path: str, dst_path: Optional[str] = None) -> str:
         """Download an artifact file or directory from a run to a local directory, and return a local path for it."""
         file = request_for_function(
             inspect.currentframe(),
