@@ -9,10 +9,10 @@ import cloudpickle
 import requests
 from ML_management.mlmanagement.jsonschema_inference import infer_jsonschema
 from ML_management.models.function_name_to_tag import FunctionNameToTag
+from mlflow.exceptions import MlflowException, RestException
 from requests_toolbelt import MultipartEncoder
 
 import mlflow
-from mlflow.exceptions import MlflowException, RestException
 
 need_active_run_functions = [
     "start_run",
@@ -87,29 +87,19 @@ def request_log_model(function_name, kwargs, extra_attrs):
         zip_file_folder = "zip_file"
         path_for_zip_file = os.path.join(temp_dir, zip_file_folder)
         if kwargs["python_model"] is not None:
-            mlflow.pyfunc.save_model(
-                path=path_for_model_folder, **kwargs_for_save_model
-            )
+            mlflow.pyfunc.save_model(path=path_for_model_folder, **kwargs_for_save_model)
 
             for delete_arg in delete_args_for_log_func:
                 del kwargs[delete_arg]
             kwargs["loader_module"] = mlflow.pyfunc.model.__name__
-            model_filename = shutil.make_archive(
-                path_for_zip_file, "zip", path_for_model_folder
-            )
+            model_filename = shutil.make_archive(path_for_zip_file, "zip", path_for_model_folder)
 
         elif kwargs["loader_module"] is not None:
             if not os.path.isdir(kwargs["data_path"]):
-                raise Exception(
-                    "Directory {0} doesn't exist".format(kwargs["data_path"])
-                )
-            model_filename = shutil.make_archive(
-                path_for_zip_file, "zip", kwargs["data_path"]
-            )
+                raise Exception("Directory {0} doesn't exist".format(kwargs["data_path"]))
+            model_filename = shutil.make_archive(path_for_zip_file, "zip", kwargs["data_path"])
         else:
-            raise Exception(
-                "Either python_model or loader_module parameter must be specified"
-            )
+            raise Exception("Either python_model or loader_module parameter must be specified")
 
         with open(model_filename, "rb") as file:
             return request(function_name, kwargs, extra_attrs, file)
@@ -141,9 +131,7 @@ def request(function_name, kwargs, extra_attrs, model_file, for_class=None):
     }
 
     multipart = MultipartEncoder(fields=files)
-    return requests.post(
-        server_ml_api, data=multipart, headers={"Content-Type": multipart.content_type}
-    )
+    return requests.post(server_ml_api, data=multipart, headers={"Content-Type": multipart.content_type})
 
 
 def send_request_to_server(function_name, kwargs, extra_attrs, for_class):
