@@ -42,9 +42,7 @@ class Model(mlflow.pyfunc.PythonModel, ABC):
                 artifact_path=pyfunc_model_name,
                 python_model=self,
                 artifacts=artifacts,
-                registered_model_name=self.model_name
-                if hasattr(self, "model_name")
-                else registered_model_name,
+                registered_model_name=self.model_name if hasattr(self, "model_name") else registered_model_name,
                 action_type=ActionType.UPLOAD,  # should this be the same as job type? can also put it into class. OR, make it new type.
                 source_model_name=self.source_model_name
                 if hasattr(self, "source_model_name")
